@@ -6,13 +6,12 @@ import ipaddress
 import findssh.threadpool
 
 PORT = 22
-SERVICE = ""
-TIMEOUT = 1.0
+TIMEOUT = 0.5
 
 
 def test_threadpool():
-    net = findssh.netfromaddress(findssh.getLANip())
-    hosts = findssh.threadpool.get_hosts(net, PORT, SERVICE, TIMEOUT)
+    net = findssh.address2net(findssh.get_lan_ip())
+    hosts = findssh.threadpool.get_hosts(net, PORT, TIMEOUT)
     for host, svc in hosts:
         assert isinstance(host, ipaddress.IPv4Address)
         assert isinstance(svc, str)
